import { useState, useEffect } from "react";
import { Link, useLocation } from "wouter";
import { useQuery } from "@tanstack/react-query";
import { User, Bell, UserCircle, LogOut, Menu } from "lucide-react";
import { Button } from "@/components/ui/button";
import { Avatar, AvatarFallback } from "@/components/ui/avatar";
import { 
  DropdownMenu, 
  DropdownMenuContent, 
  DropdownMenuItem, 
  DropdownMenuSeparator, 
  DropdownMenuTrigger 
} from "@/components/ui/dropdown-menu";
import { apiRequest } from "@/lib/queryClient";
import { useToast } from "@/hooks/use-toast";
import { CATEGORIES } from "@/lib/constants";

interface Category {
  id: number;
  name: string;
  slug: string;
  icon: string;
}

const Header = () => {
  const [location, navigate] = useLocation();
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);
  const { toast } = useToast();

  // Fetch categories
  const { data: categoriesData } = useQuery<{ categories: Category[] }>({
    queryKey: ['/api/categories'],
  });
  
  // Fetch current user
  const { data: userData, isLoading: isLoadingUser, refetch: refetchUser } = useQuery<{ user: any }>({
    queryKey: ['/api/auth/current-user'],
    retry: false,
  });

  const isLoggedIn = !!userData?.user;

  const handleLogout = async () => {
    try {
      await apiRequest('POST', '/api/auth/logout', {});
      toast({
        title: 'Déconnexion réussie',
        description: 'Vous avez été déconnecté avec succès.',
        variant: 'default',
      });
      refetchUser();
      navigate('/');
    } catch (error) {
      toast({
        title: 'Erreur',
        description: 'Une erreur est survenue lors de la déconnexion.',
        variant: 'destructive',
      });
    }
  };

  return (
    <header className="bg-gradient-to-r from-teal-600 to-teal-700 shadow-lg sticky top-0 z-50 text-white">
      {/* Main header */}
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between h-16">
          {/* Logo */}
          <div className="flex-shrink-0 flex items-center">
            <Link href="/" className="text-white font-bold text-2xl">
              Gwada<span className="text-yellow-300">Coco</span>
            </Link>
          </div>
          
          {/* Desktop navigation */}
          <div className="hidden md:ml-6 md:flex md:items-center md:space-x-4">
            <Link href="/create-listing" className="px-3 py-2 text-sm font-medium text-white hover:text-yellow-300">
              Déposer une annonce
            </Link>
            <Link href="/search" className="px-3 py-2 text-sm font-medium text-white hover:text-yellow-300">
              Rechercher
            </Link>
            <Link href="/favorites" className="px-3 py-2 text-sm font-medium text-white hover:text-yellow-300">
              Mes favoris
            </Link>
            <Link href="/messages" className="px-3 py-2 text-sm font-medium text-white hover:text-yellow-300">
              Messages
            </Link>
          </div>
          
          {/* User profile section */}
          <div className="flex items-center">
            <Button className="bg-amber-400 hover:bg-amber-500 text-teal-900 font-bold" asChild>
              <Link href="/create-listing">
                Déposer une annonce
              </Link>
            </Button>
            
            <div className="ml-4 flex items-center md:ml-6">
              {/* Notifications */}
              <Button variant="ghost" size="icon" className="text-white hover:text-yellow-300">
                <Bell className="h-5 w-5" />
              </Button>
              
              {/* Profile dropdown */}
              <div className="ml-3 relative">
                {isLoggedIn ? (
                  <DropdownMenu>
                    <DropdownMenuTrigger asChild>
                      <Button variant="ghost" size="icon">
                        <Avatar className="h-8 w-8">
                          <AvatarFallback className="bg-amber-400 text-teal-900">
                            {userData?.user.username.charAt(0).toUpperCase()}
                          </AvatarFallback>
                        </Avatar>
                      </Button>
                    </DropdownMenuTrigger>
                    <DropdownMenuContent align="end">
                      <DropdownMenuItem asChild>
                        <Link href="/profile" className="cursor-pointer flex items-center">
                          <User className="mr-2 h-4 w-4" />
                          <span>Mon profil</span>
                        </Link>
                      </DropdownMenuItem>
                      <DropdownMenuItem asChild>
                        <Link href="/messages" className="cursor-pointer flex items-center">
                          <Bell className="mr-2 h-4 w-4" />
                          <span>Notifications</span>
                        </Link>
                      </DropdownMenuItem>
                      <DropdownMenuSeparator />
                      <DropdownMenuItem onClick={handleLogout} className="cursor-pointer">
                        <LogOut className="mr-2 h-4 w-4" />
                        <span>Déconnexion</span>
                      </DropdownMenuItem>
                    </DropdownMenuContent>
                  </DropdownMenu>
                ) : (
                  <Button variant="ghost" size="icon" className="text-white hover:text-yellow-300" asChild>
                    <Link href="/login">
                      <UserCircle className="h-8 w-8" />
                    </Link>
                  </Button>
                )}
              </div>
            </div>
          </div>
          
          {/* Mobile menu button */}
          <div className="-mr-2 flex items-center md:hidden">
            <Button
              variant="ghost"
              size="icon"
              className="text-white hover:text-yellow-300"
              onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}
            >
              <Menu className="h-6 w-6" />
            </Button>
          </div>
        </div>
      </div>
      
      {/* Mobile menu */}
      {isMobileMenuOpen && (
        <div className="md:hidden bg-teal-800">
          <div className="px-2 pt-2 pb-3 space-y-1 sm:px-3">
            <Link 
              href="/create-listing" 
              className="block px-3 py-2 rounded-md text-base font-medium text-white hover:text-yellow-300 hover:bg-teal-700"
              onClick={() => setIsMobileMenuOpen(false)}
            >
              Déposer une annonce
            </Link>
            <Link 
              href="/search" 
              className="block px-3 py-2 rounded-md text-base font-medium text-white hover:text-yellow-300 hover:bg-teal-700"
              onClick={() => setIsMobileMenuOpen(false)}
            >
              Rechercher
            </Link>
            <Link 
              href="/favorites" 
              className="block px-3 py-2 rounded-md text-base font-medium text-white hover:text-yellow-300 hover:bg-teal-700"
              onClick={() => setIsMobileMenuOpen(false)}
            >
              Mes favoris
            </Link>
            <Link 
              href="/messages" 
              className="block px-3 py-2 rounded-md text-base font-medium text-white hover:text-yellow-300 hover:bg-teal-700"
              onClick={() => setIsMobileMenuOpen(false)}
            >
              Messages
            </Link>
            
            {!isLoggedIn && (
              <>
                <Link 
                  href="/login" 
                  className="block px-3 py-2 rounded-md text-base font-medium text-white hover:text-yellow-300 hover:bg-teal-700"
                  onClick={() => setIsMobileMenuOpen(false)}
                >
                  Connexion
                </Link>
                <Link 
                  href="/register" 
                  className="block px-3 py-2 rounded-md text-base font-medium text-white hover:text-yellow-300 hover:bg-teal-700"
                  onClick={() => setIsMobileMenuOpen(false)}
                >
                  Inscription
                </Link>
              </>
            )}
            
            {isLoggedIn && (
              <>
                <Link 
                  href="/profile" 
                  className="block px-3 py-2 rounded-md text-base font-medium text-white hover:text-yellow-300 hover:bg-teal-700"
                  onClick={() => setIsMobileMenuOpen(false)}
                >
                  Mon profil
                </Link>
                <button 
                  onClick={() => {
                    handleLogout();
                    setIsMobileMenuOpen(false);
                  }}
                  className="block w-full text-left px-3 py-2 rounded-md text-base font-medium text-white hover:text-yellow-300 hover:bg-teal-700"
                >
                  Déconnexion
                </button>
              </>
            )}
          </div>
        </div>
      )}
      
      {/* Categories navigation */}
      <div className="bg-white border-t border-teal-500">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="py-3 flex flex-wrap gap-4 overflow-x-auto">
            {(categoriesData?.categories || CATEGORIES).map((category) => (
              <Link 
                key={category.slug}
                href={`/categories/${category.slug}`}
                className="whitespace-nowrap text-teal-800 hover:text-amber-500 transition-colors"
              >
                <div className="flex flex-col items-center">
                  <i className={`fas ${category.icon} text-lg`}></i>
                  <span className="text-xs mt-1 font-medium">{category.name}</span>
                </div>
              </Link>
            ))}
            
            <Link href="/categories" className="whitespace-nowrap text-teal-800 hover:text-amber-500 transition-colors">
              <div className="flex flex-col items-center">
                <i className="fas fa-ellipsis-h text-lg"></i>
                <span className="text-xs mt-1 font-medium">Plus</span>
              </div>
            </Link>
          </div>
        </div>
      </div>
    </header>
  );
};

export default Header;
